package xyz.lychee.lagfixer.libs.adventure.permission;

import xyz.lychee.lagfixer.libs.adventure.util.TriState;
import xyz.lychee.lagfixer.libs.annotations.NotNull;
import xyz.lychee.lagfixer.libs.annotations.Nullable;

final class PermissionCheckers {
   static final PermissionChecker NOT_SET;
   static final PermissionChecker FALSE;
   static final PermissionChecker TRUE;

   private PermissionCheckers() {
   }

   static {
      NOT_SET = new Always(TriState.NOT_SET);
      FALSE = new Always(TriState.FALSE);
      TRUE = new Always(TriState.TRUE);
   }

   private static final class Always implements PermissionChecker {
      private final TriState value;

      private Always(final TriState value) {
         this.value = value;
      }

      public @NotNull TriState value(final @NotNull String permission) {
         return this.value;
      }

      public String toString() {
         return PermissionChecker.class.getSimpleName() + ".always(" + this.value + ")";
      }

      public boolean equals(final @Nullable Object other) {
         if (this == other) {
            return true;
         } else if (other != null && this.getClass() == other.getClass()) {
            Always always = (Always)other;
            return this.value == always.value;
         } else {
            return false;
         }
      }

      public int hashCode() {
         return this.value.hashCode();
      }

      // $FF: synthetic method
      Always(TriState x0, Object x1) {
         this(x0);
      }
   }
}
